@@ -5,8 +5,8 @@ import re
 import pprint
 import math
 import ssl
-from dummy_socket.exceptions import *
-from dummy_socket.ip_address import *
+from dummy_socket.socket.exceptions import *
+from dummy_socket.socket.ip_address import *
 
 LETTERS = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz`1234567890-=~!@#$%^&*()_+[]\;\';,./:"?><{}|'
 __doc__ = 'simple socket programming for dummies.'
@@ -19,6 +19,7 @@ __all__ = ['serve_forever(port)',
            'encryptMessage(key, message)',
            'decryptMessage(key, message)'
            ]
+MAX_BYTES = 65535
 
 def encryptMessage(key, message):
     return _translateMessage(key, message, 'encrypt')
@@ -67,10 +68,10 @@ def isValidPort(port):
         return True
     return False
 
-def serve(port, socket1, key，advanced_encryption=True, ip=getIP()):
+def serve(port, socket1, key，encryption=True, advanced_encryption=True, ip=getIP()):
     host = ip
     if advanced_encryption:
-        mySocket = ssl.wrap_socket(socket1, ssl_version=ssl.PROTOCOL_TLS, ciphers="ADH-AES256-SHA")
+        mySocket = ssl.wrap_socket(socket1, ssl_version=ssl.PROTOCOL_TLSv1_2, ciphers="ADH-AES256-SHA")
     else:
         mySocket = socket1
     if not isValidPort(port):
@@ -89,7 +90,10 @@ def serve(port, socket1, key，advanced_encryption=True, ip=getIP()):
     print("Connection from: " + str(addr))
     
     while True:
-        data = decryptMessage(key, conn.recv(8192).decode())
+        if encryption:
+            data = decryptMessage(key, conn.recv(MAX_BYTES).decode())
+        else:
+            data = conn.recv(MAX_BYTES).decode()
         if data == 'exit()':
             break
         print ("From Connected User " + conn + ' ' + addr + ": " + str(data))
@@ -103,7 +107,7 @@ def serve(port, socket1, key，advanced_encryption=True, ip=getIP()):
     conn.close()
 
 
-def serve_forever(port, socket1, key, advanced_encryption=True, ip=getIP()):
+def serve_forever(port, socket1, key, encryption=True, advanced_encryption=True, ip=getIP()):
     host = ip
     if advanced_encryption:
         mySocket = ssl.wrap_socket(socket1, ssl_version=ssl.PROTOCOL_TLS, ciphers="ADH-AES256-SHA")
@@ -125,8 +129,10 @@ def serve_forever(port, socket1, key, advanced_encryption=True, ip=getIP()):
         print ("Connection from: " + str(addr))
 
         while True:
-            data = conn.recv(e4096).decode()
-            data = decryptMessage(key, data)
+            if encryption:
+                data = decryptMessage(key, conn.recv(MAX_BYTES).decode())
+            else:
+                data = conn.recv(MAX_BYTES).decode()
             if data == 'exit()':
                 break
             print ("From Connected User: " + str(data))
